@@ -7,7 +7,7 @@
 class Help {
 
 public:
-    static void showHelp(const std::string_view& option);
+    static void showHelp(const std::string& option);
 
 };
 
