@@ -3,7 +3,7 @@
 
 #include <expected>
 #include <string>
-
+#include <vector>
 
 class Options {
 
@@ -13,7 +13,7 @@ public:
      * std::string query;
      */
     static std::expected<std::array<std::string, 4>, std::string>
-    getOptions(int argc, char** argv);
+    getOptions(int argc, const std::vector<std::string>& argVector);
 
 };
 
